﻿
namespace WpfAppCamboApp
{
    using System;
    using System.Collections.Generic;
    using System.Collections.ObjectModel;
    using Syncfusion.Windows.Controls.Gantt;

    class ViewModel
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ViewModel"/> class.
        /// </summary>
        public ViewModel()
        {
            _taskDetails= this.GetTaskDetails();
            _customScheduleSource = this.GetCustomScheduleSource();
        }

        private ObservableCollection<Model> _taskDetails;

        /// <summary>
        /// Gets or sets the task collection.
        /// </summary>
        /// <value>The task collection.</value>
        public ObservableCollection<Model> TaskDetails
        {
            get 
            {
                 return _taskDetails; 
            }

            set 
            {
                _taskDetails = value;
            }
        }

        private IList<GanttScheduleRowInfo> _customScheduleSource;

        /// <summary>
        /// Gets or sets the custom schedule source.
        /// </summary>
        /// <value>The custom schedule source.</value>
        public IList<GanttScheduleRowInfo> CustomScheduleSource
        {
            get
            {
                return _customScheduleSource;
            }

            set
            {
                _customScheduleSource = value;
            }
        }

        /// <summary>
        /// Gets the custom schedule source.
        /// </summary>
        /// <returns></returns>
        public IList<GanttScheduleRowInfo> GetCustomScheduleSource()
        {
            return new List<GanttScheduleRowInfo>
                       {
                           new GanttScheduleRowInfo
                               {
                                   TimeUnit = TimeUnit.Days,
                                   PixelsPerUnit = 45,
                                   CellTextFormat = "MMM dd"
                               }
                       };
        }

        /// <summary>
        /// Gets the task details.
        /// </summary>
        /// <returns></returns>
        ObservableCollection<Model> GetTaskDetails()
        {
            ObservableCollection<Model> task = new ObservableCollection<Model>();

            task.Add(new Model { TaskId = 1, TaskName = "Scope", StartDate = new DateTime(2011, 7, 3, 1, 0, 0), FinishDate = new DateTime(2011, 7, 14, 5, 0, 0) });
            task[0].Child.Add(new Model { TaskId = 2, TaskName = "Determine project office scope", StartDate = new DateTime(2011, 7, 3), FinishDate = new DateTime(2011, 7, 5), Range = "10-3" });
            task[0].Child.Add(new Model { TaskId = 3, TaskName = "Justify Project Offfice via business model", StartDate = new DateTime(2011, 7, 3), FinishDate = new DateTime(2011, 7, 7), Range = "10-4" });
            task[0].Child.Add(new Model { TaskId = 4, TaskName = "Secure executive sponsorship", StartDate = new DateTime(2011, 7, 3), FinishDate = new DateTime(2011, 7, 14), Range = "11-3" });
            task[0].Child.Add(new Model { TaskId = 5, TaskName = "Secure complete", StartDate = new DateTime(2011, 7, 14), FinishDate = new DateTime(2011, 7, 14), Range = "11-4" });

            task.Add(new Model { TaskId = 6, TaskName = "Risk Assessment", StartDate = new DateTime(2011, 7, 8), FinishDate = new DateTime(2011, 7, 24), Range = "11-5" });
            
            return task;
        }
    }
}
